@@ -376,9 +376,6 @@ Some more longer description.  "I suck at summaries!"  "Better than it sounds!"
 
             soup = self.make_soup(data)
 
-            if '#' in url:
-                anchorid = url.split('#')[1]
-                soup = soup.find('li',id=anchorid)
 
             if 'wordpress.com' in url:
                 bq = soup.find('div',{'class':'entry-content'})
@@ -386,15 +383,26 @@ Some more longer description.  "I suck at summaries!"  "Better than it sounds!"
                 for tag in addiv.find_all_next('div'):
                     tag.extract()
                 addiv.extract()
-            else:
-                bq = soup.find('blockquote')
-                bq.name='div'
+            elif '#' in url:
+                anchorid = url.split('#')[1]
+                if 'spacebattles.com' in url or 'sufficientvelocity.com' in url:
+                    # XF2
+                    soup = soup.find('article',{'data-content':anchorid})
+                    bq = soup.find('div',{'class':'bbWrapper'})
+                else:
+                    soup = soup.find('li',id=anchorid)
+                    bq = soup.find('blockquote')
+                    bq.name='div'
 
             for iframe in bq.find_all('iframe'):
                 iframe.extract() # calibre book reader & editor don't like iframes to youtube.
 
             for qdiv in bq.find_all('div',{'class':'quoteExpand'}):
                 qdiv.extract() # Remove <div class="quoteExpand">click to expand</div>
+            for qdiv in bq.find_all('div',{'class':re.compile(r'bbCodeBlock-(expand|shrink)Link')}):
+                qdiv.extract() # Remove <div class="quoteExpand">click to expand</div>
+            for tag in bq.find_all('div', class_="bbCodeBlock-expandContent"):
+                tag.name='blockquote'
 
             return self.utf8FromSoup(url[:url.index('/',8)+1],bq)
 
@@ -414,6 +422,17 @@ Don't&#8212e;ver&#8212d;o&#8212;that&#8212a;gain, &#27861; &#xE9;
 horizontal rules
 <hr size=1 noshade>
 <p>"Lorem ipsum dolor sit amet", consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore--et dolore magna aliqua. 'Ut enim ad minim veniam', quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
+<br>
+<br>
+Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.<br/>
+<br/>
+<br/>
+<br>
+<br>
+ <br/>
+<br/>  <br/>
+<br/>
+"Lorem ipsum dolor sit amet", consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore--et dolore magna aliqua. 'Ut enim ad minim veniam', quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.<br>
 <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
 </div>
 '''
