@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Fanficdownloader team, 2019 FanFicFare team
+# Copyright 2015 Fanficdownloader team, 2020 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the 'License');
 # you may not use this file except in compliance with the License.
@@ -40,7 +40,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.18.0"
+version="3.19.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -64,6 +64,7 @@ try:
     from calibre_plugins.fanficfare_plugin.fanficfare.geturls import get_urls_from_page, get_urls_from_imap
     from calibre_plugins.fanficfare_plugin.fanficfare.six.moves import configparser
     from calibre_plugins.fanficfare_plugin.fanficfare.six.moves import http_cookiejar as cl
+    from calibre_plugins.fanficfare_plugin.fanficfare.six import text_type as unicode
 except ImportError:
     from fanficfare import adapters, writers, exceptions
     from fanficfare.configurable import Configuration
@@ -72,6 +73,7 @@ except ImportError:
     from fanficfare.geturls import get_urls_from_page, get_urls_from_imap
     from fanficfare.six.moves import configparser
     from fanficfare.six.moves import http_cookiejar as cl
+    from fanficfare.six import text_type as unicode
 
 
 def write_story(config, adapter, writeformat,
@@ -609,4 +611,6 @@ def get_configuration(url,
     return configuration
 
 if __name__ == '__main__':
+    ## this isn't actually used by pip installed CLI.
+    ## that calls main() itself.
     main()
